log using StackedAnalysis.txt, text replace
**********************************************************
*StackedAnalysis.do

*Analyze the results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in April and May 2011.
*This file stacks the experiments for total consideration.
**********************************************************

clear
set more off

use "../scripts-experiment1/incumbentGameData.dta", clear
drop prime
*Drop folks who were assigned to instructions round 1; an error in the web design
*led them to not view the instructions at any point.
count
drop if instructionsround == 1
gen source = "Instruct1"
append using "../scripts-experiments2and3/incumbentGameData-VaryingInstructions.dta"
replace source = "Instruct2" if source == ""
append using "../scripts-experiments2and3/incumbentGameData-VaryingLottery.dta"
replace source = "Lottery" if source == ""
append using "../scripts-experiments2and3/incumbentGameData-VaryingPrime.dta"
replace source = "Prime" if source == ""
count

*Create intervention variable. THIS IS REQUIRED BY RecodeIncumbentGameData.do.
gen intervention = ""
replace intervention = " Instructions  before round 1" if instructionsround == 1 & (source == "Instruct1" | source == "Instruct2")
replace intervention = "Informed later (after round  8)"  if instructionsround == 8 & (source == "Instruct1" | source == "Instruct2")
replace intervention = "Informed later (after round 12)" if instructionsround == 12 & (source == "Instruct1" | source == "Instruct2")

replace intervention = "Lottery Payment -5000, Round  8" if lotterypay == -5000 & lotteryround == 8 & source == "Lottery"
replace intervention = "Lottery Payment -5000, Round 16" if lotterypay == -5000 & lotteryround == 16 & source == "Lottery"
replace intervention = "Lottery Payment 0, Round  8" if lotterypay == 0 & lotteryround == 8 & source == "Lottery"
replace intervention = "Lottery Payment 0, Round 16" if lotterypay == 0 & lotteryround == 16 & source == "Lottery"
replace intervention = "Lottery Payment 5000, Round  8" if lotterypay == 5000 & lotteryround == 8 & source == "Lottery"
replace intervention = "Lottery Payment 5000, Round 16" if lotterypay == 5000 & lotteryround == 16 & source == "Lottery"

replace intervention = "  Hedonic Prime" if regexm(prime,"how satisfied are you") & source == "Prime"
replace intervention = "  Informational Prime" if regexm(prime,"the average amount given") & source == "Prime"
replace intervention = "  No Prime" if prime == "" & source == "Prime"

gen lotteryhi = (lotterypay ==  5000)
gen lotterylo = (lotterypay == -5000)
label variable lotteryhi "Lottery Payment  5000, Either Round"
label variable lotterylo "Lottery Payment -5000, Either Round"
tab lotteryhi lotterylo

tab intervention, miss

*Generic recoding of variables.
include ../RecodeIncumbentGameData.do

*Drop an intervention indicator as excluded category, manually.
foreach var of varlist interv_* {
  local vlab : variable label `var'
  if ("`vlab'" == "  No Prime") {
    di "'`vlab'' is excluded intervention category."
    drop `var'
  }
}

**********************************
*"Correct" allocator retention (keep if average payment > 1200) by intervention.
**********************************
preserve
gen correct = (keepallocator == payavggt1200inrounds1_16)

di "How did deviations from 1200 influence correct decision?"
gen absdevfrom1200 = abs((1200/`denom') - payments1_16)
reg correct absdevfrom1200

*For people who didn't receive instructions until round 8 or round 12, update correct.
replace correct = 0 if intervention == "Informed later (after round  8)"
egen payments9_16 = rowtotal(pay9-pay16)
gen payavggt1200inrounds9_16 = (payments9_16/8 > 1200)
replace correct = 1 if keepallocator == 1 & payavggt1200inrounds9_16 == 1 & intervention == "Informed later (after round  8)"
replace correct = 1 if keepallocator == 0 & payavggt1200inrounds9_16 == 0 & intervention == "Informed later (after round  8)"

replace correct = 0 if intervention == "Informed later (after round 12)" 
replace correct = 1 if keepallocator == 1 & payavggt1200inrounds13_16 == 1 & intervention == "Informed later (after round 12)" 
replace correct = 1 if keepallocator == 0 & payavggt1200inrounds13_16 == 0 & intervention == "Informed later (after round 12)" 

replace source = "Instruct" if regexm(source,"Instruct")
collapse (mean) correct (count) count=keepallocator, by(intervention source)
sort source correct
by source: li intervention correct count, ab(32)
outsheet intervention correct count using "CorrectRetentionByIntervention.csv", comma replace
restore

save "forR-Stacked.dta", replace

**********************************
*Plot of proportion retaining allocator by experiment.
**********************************

gen experiment = "Experiment 1"
replace experiment = "Experiment 2" if source == "Lottery"
replace experiment = "Experiment 3" if source == "Prime"
tab experiment source

gen dumb = .
replace dumb = 6 in 1
replace dumb = 8 in 2
replace dumb = 10 in 3
replace dumb = 12 in 4
replace dumb = 14 in 5
replace dumb = 16 in 6
replace dumb = 18 in 7
label values dumb payments
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if experiment == "Experiment 1") (lpoly keepallocator payments1_16 if experiment == "Experiment 2") (lpoly keepallocator payments1_16 if experiment == "Experiment 3"), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Experiment 1" 3 "Experiment 2" 4 "Experiment 3") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/Figure02_ReelectionByExperimentAndAveragePay.eps", as(eps) preview(off) replace

*Separate smoothers on each side of 1200.
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if experiment == "Experiment 1" & payments1_16 < 12) (lpoly keepallocator payments1_16 if experiment == "Experiment 2" & payments1_16 < 12) (lpoly keepallocator payments1_16 if experiment == "Experiment 3" & payments1_16 < 12) (lpoly keepallocator payments1_16 if experiment == "Experiment 1" & payments1_16 > 12, lpattern(solid)) (lpoly keepallocator payments1_16 if experiment == "Experiment 2" & payments1_16 > 12, lpattern(dash)) (lpoly keepallocator payments1_16 if experiment == "Experiment 3" & payments1_16 > 12, lpattern(dot)), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Experiment 1" 3 "Experiment 2" 4 "Experiment 3") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))

****************************
*Separate retention smooths for each treatment in each experiment.
****************************
*Experiment 1
*(lpoly keepallocator payments1_16 if experiment == "Experiment 1" & intervention == "Informed later (after round  8)") 
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if experiment == "Experiment 1" & intervention == " Instructions  before round 1") (lpoly keepallocator payments1_16 if experiment == "Experiment 1" & intervention == "Informed later (after round 12)"), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Before round 1" 3 "After round 12") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByTreatmentAndAveragePayExper1Lpoly.eps", as(eps) preview(off) replace

*(lfit keepallocator payments1_16 if experiment == "Experiment 1" & intervention == "Informed later (after round  8)") 
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lfit keepallocator payments1_16 if experiment == "Experiment 1" & intervention == " Instructions  before round 1") (lfit keepallocator payments1_16 if experiment == "Experiment 1" & intervention == "Informed later (after round 12)"), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "Before round 1" 3 "After round 12") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByTreatmentAndAveragePayExper1Lfit.eps", as(eps) preview(off) replace

*Experiment 3
twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lpoly keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  No Prime") (lpoly keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  Hedonic Prime") (lpoly keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  Informational Prime"), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "No prime" 3 "Hedonic prime" 4 "Informational prime") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByTreatmentAndAveragePayExper3Lpoly.eps", as(eps) preview(off) replace

twoway (scatter keepallocator dumb, msize(zero) msymbol(none)) (lfit keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  No Prime") (lfit keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  Hedonic Prime") (lfit keepallocator payments1_16 if experiment == "Experiment 3" & intervention == "  Informational Prime"), ytitle(Proportion Retaining Allocator) ytitle(, size(small)) ylabel(0(.25)1, labsize(small)) xtitle(Average Payments in Rounds 1 to 16) xtitle(, size(small)) xlabel(6(2)18, valuelabel labsize(small)) legend(order(2 "No prime" 3 "Hedonic prime" 4 "Informational prime") cols(1) size(small) region(fcolor(none))) scheme(s2mono) name(Fred, replace) xsize(7.5) ysize(10) graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
graph export "../graphs/ReelectionByTreatmentAndAveragePayExper3Lfit.eps", as(eps) preview(off) replace

**********************************
*Test that proportion retaining allocator by experiment is statistically
*different above and below the cutpoint.
**********************************
bys experiment: prtest keepallocator, by(payavggt1200inrounds1_16)

**********************************
*See how much better participants who followed the 1200 token cutpoint
*strategy did in the second 16 rounds.
**********************************
preserve
gen correctcutpointstrategy = (keepallocator == payavggt1200inrounds1_16)
collapse (sum) paymentspostkeep (count) count=paymentspostkeep, by(correctcutpointstrategy)
local pay1 = paymentspostkeep in 1
local pay2 = paymentspostkeep in 2
di "Additional tokens received by those playing appropriate strategy: " `pay2' - `pay1'
di "In dollars: $" (`pay2' - `pay1')/50000
local numcorrect = count in 2
di "Per person: $" (`pay2' - `pay1')/(50000*`numcorrect')
restore

**********************************
*Demographics, payments, dates, and count of participants.
**********************************
*Demographics.
tab responsepostGender
tab responsepostGender, miss
tab responsepostEducation
tab responsepostEducation, miss
qui gen twoyearplus = (responsepostEducation == "TwoYear" | responsepostEducation == "FourYear" | responsepostEducation == "PostGrad")
tab twoyearplus
qui destring responsepostYearOfBirth, gen(yob)
qui gen age = 2011-yob
summ age
tab responsepostParticipatedGames
tab responsepostParticipatedGames, miss

*Payments.
*Show-up fee= 25 cents for anyone before April 28, 50 cents after.
qui gen day = substr(timecomplete,9,2)
qui destring day, force replace
qui gen month = substr(timecomplete,6,2)
qui destring month, force replace
qui gen completedate = mdy(month,day,2011)
qui drop showupfee
qui gen showupfee = .
qui replace showupfee = .25 if completedate < mdy(4,28,2011)
qui replace showupfee = .5 if completedate >=mdy(4,28,2011)
summ bonus showupfee
di .773+.444

*Count and dates.
tab experiment, miss
format completedate %td
tab completedate, miss

*Average time taken.
qui generate double timestarted = clock(timestart, "YMDhms")
qui generate double timecompleted = clock(timecomplete, "YMDhms")
qui gen timetaken = (timecompleted - timestarted)/(1000*60)
summ timetaken

**********************************
*Paper Appendix Table 6: summary statistics.
**********************************
egen payments5_8   = rowmean(pay5-pay8)
replace payments5_8 = payments5_8/`denom'
label variable payments5_8 "Average Payment in Rounds 5-8"
gen  payavggt1200inrounds5_8 = (payments5_8 > (1200/`denom'))
label variable payavggt1200inrounds5_8 "Average > 1200 in Rounds 5-8"

file open outf using "../papertables/TableA05_SummaryStats.csv", write replace
levelsof intervention, local(ivalues)
*Write out header.
local row ""
foreach i of local ivalues {
  local nocomma = subinstr("`i'",",","",.)
  file write outf ",`nocomma'"
}
file write outf "" _n
*Create rows of means and ses.
local fmt "%9.2f"
foreach var of varlist payavggt1200inrounds1_16 payavggt1200inrounds1_4 payavggt1200inrounds5_8 payavggt1200inrounds9_12 payavggt1200inrounds13_16 payments1_16 payments1_4 payments5_8 payments9_12 payments13_16 devpayments13_16 {
  local row : variable label `var'
  local row = subinstr("`row'",",","",.)
  local row  = "`row'"
  local row2 = ""
  foreach i of local ivalues {
    qui summ `var' if intervention == "`i'"
    local row  = "`row'," + string(`r(mean)',"%9.2f")
    local row2 = "`row2',[" + string(`r(sd)',"%9.2f") + "]"
  }
  file write outf "`row'" _n
  file write outf "`row2'" _n
}
*Counts.
file write outf "Observations"
foreach i of local ivalues {
  qui count if intervention == "`i'"
  file write outf ",`r(N)'"
}
file write outf "" _n
file close outf

******************************
*Conotrolling for age, education, and gender.
******************************
label variable age "Age in years"
qui tab responsepostEducation, gen(educ_)
drop educ_3
foreach var of varlist educ_* {
  local vlab : variable label `var'
  local lab2 = subinstr("`vlab'","responsepostEducation==","Education is ",.)
  label variable `var' "`lab2'"
}
gen male = (responsepostGender == "Male")
label variable male "Gender is male"

*Create devpayments13_16 interactions.
foreach var of varlist interv_* {
  local i = subinstr("`var'","interv_","",.)
  qui gen Xdev13_16_`i' = devpayments13_16*`var'
  local vlab : variable label `var'
  label variable Xdev13_16_`i' "`vlab'*Average deviation rounds 13-16"
}

*Simplest models.
local covars "age educ_* male"
reg keepallocator payments1_16 payments13_16 Xpayments1_16_6 Xdev13_16_6 interv_6 if interv_4 == 1 | interv_6 == 1
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 1") bracket rdec(3) 3aster replace
reg keepallocator payments1_16 payments13_16 Xpayments1_16_6 Xdev13_16_6 interv_6 `covars' if interv_4 == 1 | interv_6 == 1
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 1") bracket rdec(3) 3aster append

reg keepallocator payments1_16 payments13_16 lotteryhi if source == "Lottery"
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 2") bracket rdec(3) 3aster append
reg keepallocator payments1_16 payments13_16 lotteryhi `covars' if source == "Lottery"
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 2") bracket rdec(3) 3aster append

reg keepallocator payments1_16 payments13_16 Xpayments1_16_1 Xdev13_16_1 interv_1 if interv_1 == 1 | interv_2 == 1
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 3") bracket rdec(3) 3aster append
reg keepallocator payments1_16 payments13_16 Xpayments1_16_1 Xdev13_16_1 interv_1 `covars' if interv_1 == 1 | interv_2 == 1
outreg using "../papertables/TableA09_WithCovariates.out", se ctitle("Allocator Retention, Experiment 3") bracket rdec(3) 3aster append

save forR-Stacked.dta, replace

capture log close
